import numpy as np
import pandas as pd
import code
import sys

class Climate():
    def __init__(self, inputs):
        # attribute the parameters to the object
        self.all_inputs = inputs
        self.inputs = inputs['climate']
        for key, val in self.inputs.items():
            setattr(self, key, val)
        self.T = self.all_inputs['model']['T']

        if 'climate' in self.all_inputs['model']['read_from_file']:
            df = pd.read_csv(self.file_name)
            site = '{}_{}'.format(self.all_inputs['model']['site'], self.all_inputs['model']['treat'])
            # extract time range
            try:
                ix_start = np.where(np.array(df.year)==self.all_inputs['model']['year_start'])[0][0]
            except:
                print('ERROR (climate): invalid start year')
                sys.exit()
            
            # extract site values
            rain = np.array(df[site])[ix_start:(ix_start + self.T)]
            # calculate variability
            rain_cov = (rain - rain.mean())/rain.mean()
            # add to the mean (exogenous)
            rain_emp = self.rain_mu + rain_cov
            
            # add extra years if required
            if rain_emp.shape[0] < self.T:
                # sample from the observed heterogeneity
                extra = self.rain_mu + np.random.choice(rain_cov, self.T-rain_emp.shape[0], replace=True)
                rain_emp = np.concatenate([rain_emp,extra])

            self.rain = rain_emp
        else:
            # create the entire sequence of climate realizations
            # [self.rain_alpha, self.rain_beta] = find_beta_params(self.rain_mu, self.rain_var)
            # self.rain = np.random.beta(self.rain_alpha, self.rain_beta, self.T)
            self.rain = np.random.normal(self.rain_mu, self.rain_sd, self.T)
        
        # correct
        self.rain[self.rain < 0] = 0
        self.rain[self.rain > 1] = 1

        # add in shock if necessary
        if inputs['model']['shock']:
            self.rain[self.shock_years] = self.shock_rain